#
# spec file for package python-jupyter-collaboration
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jupyter-collaboration
Version:        3.0.0
Release:        1.3
Summary:        Jupyter Server Extension Providing Support for Y Documents
License:        BSD-3-Clause
URL:            https://github.com/jupyterlab/jupyter_collaboration
Source:         https://github.com/jupyterlab/jupyter-collaboration/archive/refs/tags/v%{version}.tar.gz#/jupyter_collaboration-%{version}-gh.tar.gz
Source99:       python-jupyter-collaboration.rpmlintrc
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 1.4}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jupyter-collaboration-ui >= 1
Requires:       python-jupyter-docprovider >= 1
Requires:       python-jupyter-server-ydoc >= 1
Provides:       python-jupyter_collaboration = %{version}-%{release}
Obsoletes:      python-jupyterlab-rtc < 1
BuildArch:      noarch
BuildRequires:  %{python_module jupyter-collaboration-ui >= 1}
BuildRequires:  %{python_module jupyter-docprovider >= 1}
BuildRequires:  %{python_module jupyter-server-ydoc-test >= 1}
BuildRequires:  %{python_module pytest}
%python_subpackages

%description
Jupyter Collaboration is a Jupyter server extension providing Support for Y Documents.

This is a meta-package for:
- jupyter-collaboration-ui
- jupyter-docprovider
- jupyter-server-ydoc

%prep
%setup -q -n jupyter-collaboration-%{version}
sed -i 's/--color=yes//' pyproject.toml

%build
# Do not install the monorepo but the metapackage
pushd projects/jupyter-collaboration
%pyproject_wheel
popd

%install
pushd projects/jupyter-collaboration
%pyproject_install
popd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test the whole stack
%pytest

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/jupyter_collaboration
%{python_sitelib}/jupyter_collaboration-%{version}.dist-info

%changelog
* Thu Nov  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
- This is a metapackge now, depending on:
  * python-jupyter-collaboration_ui
  * python-jupyter-docprovider
  * python-jupyter-server-ydoc
* Thu Nov  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.1.5
  * Backport 'Initialize and update the ydoc path property' #342
    [#357] (@brichet)
  * [2.x] Support @jupyter/ydoc 2.x #316 (@fcollonval)
* Thu Oct 24 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.4:
  * Backport 'Update jupyter_ydoc and pycrdt_websocket
    dependencies' #367 #376 (@brichet)
  * Backport 'Fix model format' #368 #369 (@davidbrochart)
  * Backport 'Fix ignoring AnyIO warnings in tests' #359 #362
    (@brichet)
  * Backport 'Fix mypy' #358 #361 (@brichet)
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.1.2
  * Start ystore in a task #302 (@davidbrochart)
  * adding await ystore start method in prepare method #299
    (@jzhang20133)
  * Backport 'handle exception when websocket server start room
    failed' #289 #298 (@jzhang20133)
  * Backport 'Log (instead of raise) exceptions when running as a
    server extension' #295 #297 (@Zsailer)
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.11
  [#]# Enhancements made
  * Make user's cursor "tooltip-on-hover" faster and wider #259
    (@jzhang20133)
  [#]# Bugs fixed
  * Fix releaser #268 (@davidbrochart)
  * Fix slow room opening #264 (@davidbrochart)
  * Use WebSocket _room_id attribute directly #266 (@davidbrochart)
- Release 2.0.6
  [#]# Enhancements made
  * Make user's cursor "tooltip-on-hover" faster and wider #259
    (@jzhang20133)
  [#]# Bugs fixed
  * Fix slow room opening #264 (@davidbrochart)
- Release 2.0.5
  * Fix concurrent room initialization #255 (@davidbrochart)
- Release 2.0.4
  * adding awareness event when open and close websockets #246
    (@jzhang20133)
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.3
  * Fix cancellation of file save operation #241 (@davidbrochart)
  * Call get with options of type IFetchOptions #238
    (@davidbrochart)
- Release 2.0.2
  * Handle last_modified only in FileLoader #232 (@davidbrochart)
  * Fix file saving #231 (@davidbrochart)
- Fix python39-ipython removal fallout
  * Don't require jupyterlab to build
  * Don't test on python39
* Mon Jan 22 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * Revert PR #170 #228 (@davidbrochart)
- Update to 2.0.0
  * Adds a flag to disable RTC #177 (@hbcarlos)
  * Improves chat #173 (@hbcarlos)
  * Adds restore and ovewrite messages #170 (@hbcarlos)
  * Improves error handling when the file does not exist #175
    (@hbcarlos)
  * Use fileId instead of path in the store #174 (@hbcarlos)
  * Adds restore and ovewrite messages #170 (@hbcarlos)
- Ignore that pycrdt is still in incubation phase
  gh#jupyter-server/jupyter_ydoc#211
* Sun Jan 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.2.1
  [#]# Maintenance and upkeep improvements
  * Fix CI (Backport #221 into 1.x) #224 (@martinRenou)
  * Fix for last_modified being None #223 (@martinRenou)
- Release 1.2.0
  [#]# Maintenance and upkeep improvements
  * Backport #172 on branch 1.x (Remove print) #188 (@fcollonval)
- Release 1.1.0
  [#]# Enhancements made
  * Backport #177: Adds a flag to disable RTC #178 (@hbcarlos)
- Release 1.0.1
  * Support ypy-websocket v0.12 #168 (@davidbrochart)
  * Chat subprotocol #167 (@hbcarlos)
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Mon Jun 12 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.0.0
  * Remove spurious ' #156 (@krassowski)
  * Add share link feature #150 (@fcollonval)
  * Improve code architecture #146 (@fcollonval)
  * Add logger for file editor #145 (@fcollonval)
  * Emit events for collaborative sessions #139 (@hbcarlos)
  * Support file types #154 (@hbcarlos)
  * Fix injecting user menu bar in top bar. #149 (@fcollonval)
  * Wait for the document to be synced #148 (@fcollonval)
  * Fix asyncio.Task type for python<=3.8 #143 (@davidbrochart)
  * ... many more during 1.0.0alpha*: See CHANGELOG.md
- Use the new jupyter-collaboration name, obsolete the old names
  jupyter-server-ydoc and jupyterlab-rtc
* Mon Mar 20 2023 Ben Greiner <code@bnavigator.de>
- Update to jupyter_server_ydoc 0.8.0
  * Creates document session #108 (@hbcarlos)
* Sun Feb 12 2023 Ben Greiner <code@bnavigator.de>
- Downgrade to v0.6.1
  * jupyterlab, the only consumer, requires jupyter-server-ydoc<0.7
  * v0.6.2 has been yanked
* Sun Feb  5 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v0.7
- Last version to use the name jupyter-server-ydoc
